#
# spec file for package osmo-iuh
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           osmo-iuh
Version:        1.6.0
Release:        1.4
Summary:        Osmocom code for the Iuh interface (HNBAP, RUA, RANAP)
License:        AGPL-3.0-or-later
Group:          Hardware/Mobile
URL:            https://osmocom.org/projects/osmohnbgw/wiki

Source:         https://github.com/osmocom/osmo-iuh/archive/%version.tar.gz
BuildRequires:  automake >= 1.9
BuildRequires:  libtool >= 2
BuildRequires:  lksctp-tools-devel
BuildRequires:  pkg-config >= 0.20
# python3 for asn1tostruct.py
BuildRequires:  python3
BuildRequires:  pkgconfig(libasn1c) >= 0.9.30
BuildRequires:  pkgconfig(libosmo-netif) >= 1.5.0
BuildRequires:  pkgconfig(libosmo-sigtran) >= 1.9.0
BuildRequires:  pkgconfig(libosmocore) >= 1.10.0
BuildRequires:  pkgconfig(libosmoctrl) >= 1.10.0
BuildRequires:  pkgconfig(libosmogb) >= 1.10.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.10.0
BuildRequires:  pkgconfig(libosmovty) >= 1.10.0

%description
Osmocom code for the Iuh interface (HNBAP, RUA, RANAP)

%package -n libosmo-hnbap0
Summary:        Home Node B Application Part library
Group:          System/Libraries

%description -n libosmo-hnbap0
Osmocom code for the Home Node B Application Part. HNBAP is a control protocol
found in Home Node B networks on the Iu-h interface.

%package -n libosmo-hnbap-devel
Summary:        Development files for Osmocom HNBAP library
Group:          Development/Libraries/C and C++
Requires:       libosmo-hnbap0 = %version-%release

%description -n libosmo-hnbap-devel
This subpackage contains libraries and header files for developing
applications that want to make use of libosmo-hnbap.

%package -n libosmo-ranap7
Summary:        Radio Access Network Application Part library
Group:          System/Libraries

%description -n libosmo-ranap7
Osmocom code for the Radio Access Network Application Part of the Iu-h
interface.

%package -n libosmo-ranap-devel
Summary:        Header files for the Osmocom RANAP library
Group:          Development/Libraries/C and C++
Requires:       libosmo-ranap7 = %version-%release

%description -n libosmo-ranap-devel
Osmocom code for the Radio Access Network Application Part of the Iu-h
interface.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmo-ranap.

%package -n libosmo-rua0
Summary:        RANAP User Adaption signalling library
Group:          System/Libraries

%description -n libosmo-rua0
Osmocom code for the RANAP User Adaption signalling.

%package -n libosmo-rua-devel
Summary:        Header files for the Osmocom RUA library
Group:          Development/Libraries/C and C++
Requires:       libosmo-rua0 = %version-%release

%description -n libosmo-rua-devel
Osmocom code for the RANAP User Adaption signalling.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmo-rua.

%package -n libosmo-sabp1
Summary:        Osmocom Service Area Broadcast Protocol library
Group:          System/Libraries

%description -n libosmo-sabp1
Osmocom code for the Service Area Broadcast Protocol interface.

%package -n libosmo-sabp-devel
Summary:        Header files for the Osmocom SABP library
Group:          Development/Libraries/C and C++
Requires:       libosmo-sabp1 = %version-%release

%description -n libosmo-sabp-devel
Osmocom code for the Service Area Broadcast Protocol interface.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmo-sabp.

%prep
%autosetup -p1

%build
echo "%version" >.tarball-version
autoreconf -fi
%configure \
    --disable-static \
    --docdir="%_docdir/%name" \
    --with-systemdsystemunitdir="%_unitdir"
%make_build

%install
%make_install
find "%buildroot" -type f -name "*.la" -delete -print

%check
if ! %make_build check; then
	find . -type f -name testsuite.log -exec cat "{}" "+"
%ifnarch ppc ppc64
	exit 1
%endif
fi

%ldconfig_scriptlets -n libosmo-hnbap0
%ldconfig_scriptlets -n libosmo-ranap7
%ldconfig_scriptlets -n libosmo-rua0
%ldconfig_scriptlets -n libosmo-sabp1

%files -n libosmo-hnbap0
%license COPYING
%_libdir/libosmo-hnbap.so.*

%files -n libosmo-hnbap-devel
%dir %_includedir/osmocom/
%dir %_includedir/osmocom/hnbap/
%_includedir/osmocom/hnbap/*
%_libdir/libosmo-hnbap.so
%_libdir/pkgconfig/libosmo-hnbap.pc

%files -n libosmo-ranap7
%_libdir/libosmo-ranap.so.*

%files -n libosmo-ranap-devel
%dir %_includedir/osmocom/
%_includedir/osmocom/ranap/
%_libdir/libosmo-ranap.so
%_libdir/pkgconfig/libosmo-ranap.pc

%files -n libosmo-rua0
%_libdir/libosmo-rua.so.*

%files -n libosmo-rua-devel
%dir %_includedir/osmocom/
%_includedir/osmocom/rua/
%_libdir/libosmo-rua.so
%_libdir/pkgconfig/libosmo-rua.pc

%files -n libosmo-sabp1
%_libdir/libosmo-sabp.so.1*

%files -n libosmo-sabp-devel
%dir %_includedir/osmocom/
%_includedir/osmocom/sabp/
%_libdir/libosmo-sabp.so
%_libdir/pkgconfig/libosmo-sabp.pc

%changelog
* Sat Oct 26 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.0
  * Add ranap_decode_rab_releaseditemies_fromlist()
  * hnbap_common: more verbose error messages
* Thu Apr 11 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.5.1
  * ranap_transp_layer_addr_decode2(): Fix decoding X.213 IPv4
    address len=7
  * iu_client: Use local variable to track conn_id
  * iu_client: Handle empty CR and InitialUE Message in DATA.ind
* Wed Nov  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.5.0
  * fix PDU leaks in rua_generate_*() functions
  * fix leak in ranap_new_transp_layer_addr()
* Thu May 18 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4.0
  * No changelog was provided
* Wed Aug  3 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.0
  * ranap_common: add decoder for RAB SetupOrModifyItemFirst
  * ranap_common_cn: add functions for direct access to decoder
  * ranap_common_ran: add decoder for CN/MSC originated messages
  * ranap_common: add decoder for RAB-FailedList and RAB-ReleaseList
  * Make logging message about received RANAP message more meaningful
  * move new_transp_layer_addr to public API
* Sat Apr  2 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.0
  * Drop osmo-hnbgw
  * Introduce dynamic log category for libosmo-rua/hnbap
- Drop harden_osmo-hnbgw.service.patch
* Fri Nov 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.1.0
  * Provide libosmo-hnbap and libosmo-rua as a public shared
    library
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_osmo-hnbgw.service.patch
* Sun Mar 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.7.0
  * Change default SCTP conn NULL->127.0.0.1 to localhost->localhost
- Drop 0001-iu_client-uses-gprs_msgb.h.patch, damncode.diff
* Sat Aug  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 0.6.1
  * Fix compilation with gcc-10
* Sat Jun  6 2020 Jan Engelhardt <jengelh@inai.de>
- Set CFLAGS+=-fcommon.
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 0.6.0
  * sabp: Generate C/H files for SABP; create libosmo-sabp
  * sabp: Add Procedure Codes and IEI constants to CommonDataTypes
  * sabp: fixup SABP ASN.1 to avoid IOC (which are not supported
    by our toolchain)
  * sabp: Initial import of SABP ASN.1 from 3GPP TS 25.419 V11.1.0
    (2013-03)
  * hnbgw: Add libosmoctrl's VTY CTRL command initialization
  * iu_client: allow to control the notifications
- Add subpackage for libosmo-sabp
- Update patch:
  * 0001-iu_client-uses-gprs_msgb.h.patch
* Thu Aug 15 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.5.0
  * osmo-hnbgw: reply with RESET ACK when receiving a RESET
  * Add VTY reference manual
- Add damncode.diff
* Thu Feb 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 0.4.0
  * add a VTY command which shows a specific HNB
  * hnbgw: vty: add SCCP related vty commands
  * fix decoding of incoming X.213 NSAP addr
  * Full changelog:
    http://git.osmocom.org/osmo-iuh/plain/debian/changelog?h=0.4.0
- Remove patches (fixed upstream):
  * 0001-fix-return-values.patch
  * reproducible.patch
- Package service file
* Mon Jan  7 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to make package build reproducible
  (boo#1047218)
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.3.0
  * osmo-hnbgw: auto-config local and remote PCs if omitted
  * osmo-hnbgw: don't configure specific local IP address for STP connection
  * hnbgw: use proper VTY port number defined in libosmocore (4261)
  * vty: tweak / improve HNB and cnlink introspection
  * Add control interface
  * ensure unique CellIDs in HNB-GW
- Remove
  0001-fix-compiler-warning-implicit-function-declaration-i.patch
* Thu Mar 22 2018 jengelh@inai.de
- Show testsuite.log on failure. Now, always run it on PPC.
* Mon Jan  1 2018 jengelh@inai.de
- Add 0001-fix-return-values.patch,
  0001-iu_client-uses-gprs_msgb.h.patch
* Wed Dec 27 2017 mardnh@gmx.de
- Update to new upstream release 0.2.0
  * No changelog was provided
- Add patch:
  * 0001-fix-compiler-warning-implicit-function-declaration-i.patch
- Specfile cleanup
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream snapshot 0.0~g435
  * Better capture for PS Data
  * osmo-hnbgw, hnb-test: allow configuring VTY address
  * hnbgw: set default RNC ID to 23 (for testing)
  * UE Register: fix: free ies when no IMSI is found
  * ranap: make X.213 NSAP 160 bits long, zero padded
  * hnbgw: Fix crash if cnlink fails to connect
* Mon Feb  8 2016 jengelh@inai.de
- Initial package (version 0.0~g282 / 6a62e549cdede)
  for build.opensuse.org
